package fr.example.queryloader;

import java.util.List;
import java.util.concurrent.BlockingQueue;

import fr.example.queryloader.util.SQLQuery;

/**
 * La classe {@code QueryLoaderRunnable} est executee dans un thread et execute
 * les requetes vers la base de donnees.
 * 
 * @author jaubin
 *
 */
public class QueryLoaderRunnable implements Runnable {

	/**
	 * La liste des requetes a traiter.
	 */
	private BlockingQueue<SQLQuery> requestQueue;
	
	/**
	 * Indicateur de fin du thread.
	 */
	private volatile boolean isTerminated;
	
	/**
	 * Constructeur.
	 * @param rq la liste des requetes a traiter.
	 * @thhrows IllegalArgumentException si un des parametres de la methode est {@code null}.
	 */
	public QueryLoaderRunnable(final BlockingQueue<SQLQuery> rq) throws IllegalArgumentException {
		if (rq == null) {
			throw new IllegalArgumentException("rq is null");
		}
		this.requestQueue = rq;
		this.isTerminated = false;
	}
	
	/**
	 * @see java.lang.Runnable#run()
	 */
	@Override
	public void run() {
		try {
			while (!isTerminated || !requestQueue.isEmpty()) {
				SQLQuery query = requestQueue.take();
				// Do someting
 			}
		} catch (InterruptedException e) {
			System.err.println("Aborting thread.");
			e.printStackTrace();
		}
	}

	/**
	 * Marque le thread comme devant se terminer.
	 */
	public void setTerminated() {
		this.isTerminated = true;
	}
}
